@@ -8,7 +8,7 @@ csvLens2df <- function(file){
     #D <- read.csv(file[i], quote='"', check.names = F, stringsAsFactors = F) #fileEncoding = "UTF-8-BOM")
     D <- read_csv(file[i], na=character(), quote='"', trim_ws = FALSE, progress = show_progress()) %>%
       mutate(across(where(is.numeric), as.character)) %>% 
-      mutate(across(where(is.character), tidyr::replace_na,"")) %>% as.data.frame(stringsAsFactors=FALSE)
+      mutate(across(where(is.character), tidyr::replace_na,"")) %>% as.data.frame()
 
     if (i>1){
       l <- intersect(l,names(D))
@@ -56,7 +56,7 @@ csvLens2df <- function(file){
   DATA$ID <- DATA$DE
   DI <- DATA$DI
   URL <- DATA$URL
-  DATA <- data.frame(lapply(DATA,toUpper),stringsAsFactors = FALSE)
+  DATA <- data.frame(lapply(DATA,toUpper))
   DATA$DI <- DI
   DATA$URL <- URL
   DATA$AU_CO <- "NA"
