@@ -7,13 +7,10 @@ csvScopus2df <- function(file){
   
   ## import all files in a single data frame
   for (i in 1:length(file)){
-    #D <- rio::import(file[i], quote='"')
-    #D <- read.csv(file[i], quote='"', check.names = F, stringsAsFactors = F)
-
     D <- read_csv(file[i], na=character(), quote='"', trim_ws = FALSE, progress = show_progress(),
                   col_types = cols(.default = col_character())) %>%  # Introduced to remove cols parsing errors
       #mutate(across(!where(is.numeric), as.character)) %>%   # not yet necessary with the inclusion of previuos line
-      mutate(across(where(is.character), tidyr::replace_na,"")) %>% as.data.frame(stringsAsFactors=FALSE)
+      mutate(across(where(is.character), tidyr::replace_na,"")) %>% as.data.frame()
     
     if (i>1){
       l <- intersect(l,names(D))
@@ -47,7 +44,7 @@ csvScopus2df <- function(file){
  
   DI <- DATA$DI
   URL <- DATA$URL
-  DATA <- data.frame(lapply(DATA,toupper),stringsAsFactors = FALSE)
+  DATA <- data.frame(lapply(DATA,toupper))
   DATA$DI <- DI
   DATA$URL <- URL
   return(DATA)
