@@ -7,13 +7,14 @@
 #' @param M is a bibliographic data frame obtained by the converting function \code{\link{convert2df}}.
 #'        It is a data matrix with cases corresponding to manuscripts and variables to Field Tag in the original SCOPUS and Clarivate Analytics WoS file.
 #' @param sep is the field separator character. This character separates citations in each string of CR column of the bibliographic data frame. The default is \code{sep = ";"}.
-#' @param fast.search is logical. if true, the function calculates local citations only for 25 percent top cited documents.
+#' @param fast.search is logical. If true, the function calculates local citations only for 25 percent top cited documents.
+#' @param verbose is a logical.  If TRUE, results are printed on screen.
 #' @return an object of \code{class} "list" containing author local citations and document local citations.
 #'
 #' 
 #' @examples
 #'  
-#' data(scientometrics)
+#' data(scientometrics, package = "bibliometrixData")
 #' 
 #' CR <- localCitations(scientometrics, sep = ";")
 #'
@@ -27,14 +28,14 @@
 #' 
 #' @export
 
-localCitations <- function(M, fast.search=FALSE, sep = ";"){
+localCitations <- function(M, fast.search=FALSE, sep = ";", verbose = FALSE){
   
   M$TC[is.na(M$TC)] <- 0
   if (isTRUE(fast.search)){
     loccit=quantile(as.numeric(M$TC),0.75, na.rm = TRUE)
   } else {loccit=1}
   
-  H=histNetwork(M,min.citations = loccit, sep=sep, network=FALSE)
+  H=histNetwork(M,min.citations = loccit, sep=sep, network=FALSE, verbose = verbose)
   LCS=H$histData
   M=H$M
   rm(H)
