@@ -32,6 +32,7 @@
 #' @importFrom dplyr cummean
 #' @importFrom dplyr count
 #' @importFrom dplyr desc
+#' @importFrom dplyr bind_rows
 #' @importFrom dplyr group_by
 #' @importFrom dplyr mutate
 #' @importFrom dplyr mutate_at
@@ -72,9 +73,11 @@
 #' @importFrom tidyr unite
 #' @importFrom tidyr starts_with
 #' @importFrom tidyr unnest
+#' @importFrom graphics abline
 #' @importFrom grDevices adjustcolor
 #' @importFrom grDevices dev.off
 #' @importFrom grDevices pdf
+#' @importFrom grDevices chull
 #' @importFrom grDevices heat.colors
 #' @importFrom DT DTOutput
 #' @importFrom DT renderDT
@@ -84,18 +87,18 @@
 #' @importFrom rscopus author_df_orig
 #' @importFrom rscopus author_search
 #' @importFrom rscopus get_complete_author_info
-#' @importFrom RColorBrewer brewer.pal
+# @importFrom RColorBrewer brewer.pal
 #' @importFrom FactoMineR MCA
 #' @importFrom FactoMineR CA
 #' @importFrom FactoMineR PCA
-#' @importFrom factoextra get_mca_var
-#' @importFrom factoextra get_mca_ind
-#' @importFrom factoextra get_ca_row
-#' @importFrom factoextra get_ca_col
-#' @importFrom factoextra fviz_nbclust
-#' @importFrom factoextra fviz_cluster
-#' @importFrom factoextra fviz_dend
-#' @importFrom factoextra hcut
+# @importFrom factoextra get_mca_var
+# @importFrom factoextra get_mca_ind
+# @importFrom factoextra get_ca_row
+# @importFrom factoextra get_ca_col
+# @importFrom factoextra fviz_nbclust
+# @importFrom factoextra fviz_cluster
+# @importFrom factoextra fviz_dend
+# @importFrom factoextra hcut
 #' @importFrom igraph as_long_data_frame
 #' @importFrom igraph get.edgelist
 #' @importFrom igraph graph_from_data_frame
@@ -723,3 +726,10 @@ CheckArtCon <- function(x, check) {
     return(FALSE)
   }
 }
+
+# color palette
+colorlist <- function(){
+  c("#E41A1C","#377EB8","#4DAF4A","#984EA3","#FF7F00","#A65628","#F781BF","#999999","#66C2A5","#FC8D62","#8DA0CB","#E78AC3","#A6D854","#FFD92F"
+             ,"#B3B3B3","#A6CEE3","#1F78B4","#B2DF8A","#33A02C","#FB9A99","#E31A1C","#FDBF6F","#FF7F00","#CAB2D6","#6A3D9A","#B15928","#8DD3C7","#BEBADA"
+             ,"#FB8072","#80B1D3","#FDB462","#B3DE69","#D9D9D9","#BC80BD","#CCEBC5")
+}
